@@ -20,6 +20,12 @@ class pycmCIError(Exception):
     pass
 
 
+class pycmAverageError(Exception):
+    """Average error class."""
+
+    pass
+
+
 class pycmCompareError(Exception):
     """Compare error class."""
 
